@@ -1,9 +1,10 @@
 /*
- *  Copyright (c) 2004 Szombathelyi Gyrgy <gyurco@freemail.hu>
+ *  Copyright (c) 2004 Szombathelyi György <gyurco@freemail.hu>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
- *  License version 2 as published by the Free Software Foundation.
+ *  License as published by the Free Software Foundation; either
+ *  version 2 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -30,7 +31,7 @@ uint SID::mAlgRidBase = 1000;
 
 SID::SID()
 {
-  mRid = 0; mSid = QString::null; mDom = QString::null;
+  mRid = 0; mSid = QString::null; mDom = QString::null;	//krazy:exclude=nullstrassign for old broken gcc
 }
 
 SID::SID( const SID &sid )
@@ -83,7 +84,7 @@ void SID::setSID( const QString &sid )
   QString rid;
   
   mSid = sid;
-  pos = sid.findRev( '-' );
+  pos = sid.lastIndexOf( '-' );
   mDom = sid.left( pos );
   rid = sid.right( sid.length() - pos - 1 );
   mRid = rid.toUInt();
